@@ -1,31 +1,20 @@
 /*
  * This file is part of LibKGAPI library
  *
- * Copyright (C) 2013  Daniel Vrátil <dvratil@redhat.com>
+ * SPDX-FileCopyrightText: 2013 Daniel Vrátil <dvratil@redhat.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
 #ifndef LIBKGAPI2_EVENTMODIFYJOB_H
 #define LIBKGAPI2_EVENTMODIFYJOB_H
 
 #include "modifyjob.h"
+#include "enums.h"
 #include "kgapicalendar_export.h"
 
+#include <QScopedPointer>
+
 namespace KGAPI2 {
 
 /**
@@ -38,6 +27,10 @@ class KGAPICALENDAR_EXPORT EventModifyJob : public KGAPI2::ModifyJob
 {
     Q_OBJECT
 
+    Q_PROPERTY(KGAPI2::SendUpdatesPolicy sendUpdates
+               READ sendUpdates
+               WRITE setSendUpdates
+               NOTIFY sendUpdatesChanged)
   public:
 
     /**
@@ -69,6 +62,12 @@ class KGAPICALENDAR_EXPORT EventModifyJob : public KGAPI2::ModifyJob
      */
     ~EventModifyJob() override;
 
+    KGAPI2::SendUpdatesPolicy sendUpdates() const;
+    void setSendUpdates(KGAPI2::SendUpdatesPolicy updatesPolicy);
+
+  Q_SIGNALS:
+    void sendUpdatesChanged(KGAPI2::SendUpdatesPolicy policy);
+
   protected:
 
     /**
@@ -86,7 +85,7 @@ class KGAPICALENDAR_EXPORT EventModifyJob : public KGAPI2::ModifyJob
 
   private:
     class Private;
-    Private * const d;
+    QScopedPointer<Private> const d;
     friend class Private;
 
 };
